@@ -4,7 +4,7 @@ from .constants import INSTANCES
 from .handlers import CfgParser
 
 
-def get_config(name: str = "default", **kwargs):
+def get_config(name: str = "cfgpie", **kwargs) -> CfgParser:
     if name not in INSTANCES:
         # a strong reference is required
         instance: CfgParser = CfgParser(name, **kwargs)
